#
# spec file for package soapy-rtlsdr
#
# Copyright (c) 2021 SUSE LLC.
# Copyright (c) 2017, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%define soapy_modver 0.8
%define soapy_modname soapysdr%{soapy_modver}-module-rtlsdr

Name:           soapy-rtlsdr
Version:        0.3.2
Release:        2.8
Summary:        SoapySDR RTL-SDR support module
License:        MIT
Group:          Hardware/Other
Url:            https://github.com/pothosware/SoapyRTLSDR/wiki
#Git-Clone:     https://github.com/pothosware/SoapyRTLSDR.git
Source:         https://github.com/pothosware/SoapyRTLSDR/archive/soapy-rtl-sdr-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(SoapySDR)
BuildRequires:  pkgconfig(librtlsdr)

%description
Soapy RTL-SDR - RTL-SDR device support for Soapy SDR.
A Soapy module that supports RTL-SDR devices within the Soapy API.

%package -n %{soapy_modname}
Summary:        SoapySDR RTL-SDR support module
Group:          System/Libraries

%description -n %{soapy_modname}
Soapy RTL-SDR - RTL-SDR device support for Soapy SDR.
A Soapy module that supports RTL-SDR devices within the Soapy API.

%prep
%setup -q -n SoapyRTLSDR-soapy-rtl-sdr-%{version}

%build
%cmake
make VERBOSE=1 %{?_smp_mflags}

%install
%cmake_install

%files -n %{soapy_modname}
%license LICENSE.txt
%doc Changelog.txt README.md
%dir %{_libdir}/SoapySDR
%dir %{_libdir}/SoapySDR/modules%{soapy_modver}
%{_libdir}/SoapySDR/modules%{soapy_modver}/librtlsdrSupport.so

%changelog
* Tue Jul  6 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- SoapySDR version bumped to 0.8
* Tue Feb 23 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 0.3.2
  * Revert pull request #49, freq can be set while stream active
  * Fix setFrequencyCorrection exceptional return code
  * Fix to read back after setting sampleRate, ppm,
    and centerFrequency; or throw on invalid input
  * Fix rtlsdr_get_tuner_gain() in setupStream() (closes #51)
- Update to version 0.3.1
  * Refactor and fix open by serial implementation
  * Support recent rtlsdr_set_bias_tee() API
  * Do not advertise full duplex capability
  * Possible fix for issue with misaligned center frequency
  * Implement hardware time API using absolute sample count
* Thu Dec 13 2018 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 0.3.0
  * Digital AGC now available through "digital_agc" setting
  * Gain mode now affects rtlsdr_set_tuner_gain_mode()
  * GetHardwareKey() returns the actual tuner type
* Sat Nov 10 2018 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update soapy-module version 0.6 -> 0.7
* Fri Jun  8 2018 wk@ire.pw.edu.pl
- Update to version 0.2.5
  * Deactivate the stream thread in closeStream()
  * Fix clipping for the int8 conversion support
- Update to version 0.2.4
  * readStream - also drop remainder buffer on reset
  * Fixed configuration input for num async buffers
* Fri May  5 2017 mardnh@gmx.de
- Update to version 0.2.3
  * Added support for frequency correction API
  * Separate buffer count for ring buffer and usb
  * Larger buffer size - same as rtl defaults
  * Use atomics for ring buffer implementation
  * Use Format string constants for stream types
* Wed Apr 19 2017 mardnh@gmx.de
- renamed packages according the debian package name from upstream
* Thu Apr 13 2017 mardnh@gmx.de
- Update to version 0.2.2 (tagged release)
- renamed package from SoapyRTLSDR to soapy-rtlsdr
- specfile cleanup
* Tue Jan  3 2017 mardnh@gmx.de
- Update to version 0.2.2.git1474857654.12aa0a2:
  * rtl: updated changelog for 0.2.0 tag
  * Fixed debian control Maintainer/Uploaders
  * E4000 and FC001x tuner type updates
  * Balace initial gain
  * Fix getGain() for E4000
  * separate top level changelog
  * rtl: updated changelog for 0.2.1 tag
  * Implement building for big endian
  * changelog entry for big endian patch
  * debian: update files for SoapySDR module ABI format
  * rtl: updated changelog for 0.2.2 tag
  * streaming: use format constants
  * streaming - Use atomics for ring buffer
  * streaming - check buf count under lock
* Tue Dec  8 2015 mardnh@gmx.de
- Update to version 0.1.0.git1448058200.1eeff20:
  + rtl: filled in the hasGainMode overload
  + rtl: Added support for the direct access buffer API
  + Update for 0.4.0 and arguments/settings
  + Handle when rtlsdr_open fails
  + Fix direct_samp setting and convert to option string /w descriptions
  + bool != ranged
  + travis: added travis ci for SoapyRTLSDR
* Sun Oct 11 2015 mardnh@gmx.de
- initial package
